#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""Application informations."""

APP_NAME = "usb-imager"
APP_TITLE = "USB-Imager"
APP_DESCRIPTION = \
    "GUI-Application to write bootable disk images to USB key."

APP_LICENSE = "GPLv3"
APP_COPYRIGHT = "© 2021-2022"

APP_VERSION = "2.1.0"

APP_ORGANISATION = "Secu-Design®"
APP_ID = "com.secu-design.app.usb-imager"
APP_AUTHOR = "Skynet-Devel"
APP_AUTHOR_EMAIL = "skynet-devel.tech@secu-design.com"

APP_URL_GITLAB = "https://gitlab.com/secu-design/usb-imager"
APP_URL_PYPI = "https://pypi.org/project/usb-imager"

APP_ABOUT = f"""\
Copyright {APP_COPYRIGHT} by {APP_ORGANISATION}.
Released under the {APP_LICENSE} license.

Author:  {APP_AUTHOR}
E-mail:  {APP_AUTHOR_EMAIL}

Websites:
{APP_URL_GITLAB}
{APP_URL_PYPI}

Please send me feedback if you like
USB-Imager or if you find bugs.
"""
